.. _WWW-md-base-app:

Material design Base application
================================

``md_base`` is a complete replacement for the bootstrap based ``base`` application.
It's UI is based on google's Material Design libraries.

Status
~~~~~~

md-base is currently not really usable as the default UI, see the list of issues :bug:`3397`.
